import sys
import typing

GenericType = typing.TypeVar("GenericType")

def complete(word, namespace, private): ...
def complete_indices(word, namespace, obj, base): ...
def complete_names(word, namespace): ...
def is_dict(obj): ...
def is_struct_seq(obj): ...
