import sys
import typing

GenericType = typing.TypeVar("GenericType")

def load_id(id: typing.Any):
    """Set the selection ID.

    :type select: int
    :param id:  Number (32-bit uint).
    :type id: typing.Any
    """

    ...
